@@ -217,18 +217,9 @@ LALFindChirpInjectSignals (
   }
 
   /* set up units for the transfer function */
-  {
-    RAT4 negOne = { -1, 0 };
-    LALUnit unit;
-    LALUnitPair pair;
-    pair.unitOne = &lalADCCountUnit;
-    pair.unitTwo = &lalStrainUnit;
-    LALUnitRaise( status->statusPtr, &unit, pair.unitTwo, &negOne );
-    CHECKSTATUSPTR( status );
-    pair.unitTwo = &unit;
-    LALUnitMultiply( status->statusPtr, &(detector.transfer->sampleUnits),
-        &pair );
-    CHECKSTATUSPTR( status );
+  if (XLALUnitDivide( &(detector.transfer->sampleUnits),
+                      &lalADCCountUnit, &lalStrainUnit ) == NULL) {
+    ABORTXLAL(status);
   }
 
   /* invert the response function to get the transfer function */
